@@ -1,22 +1,22 @@
 /*
- * Copyright (c) 2003 by the gtk2-perl team (see the file AUTHORS)
+ * Copyright (C) 2003 by the gtk2-perl team (see the file AUTHORS for the full
+ * list)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Library General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or (at your
+ * option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * This library is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+ * License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the 
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
- * Boston, MA  02111-1307  USA.
+ * You should have received a copy of the GNU Library General Public License
+ * along with this library; if not, write to the Free Software Foundation,
+ * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
  *
- * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/gperl.h,v 1.15 2003/08/29 02:15:42 muppetman Exp $
+ * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/gperl.h,v 1.24 2003/10/02 07:12:08 muppetman Exp $
  */
 
 #ifndef _GPERL_H_
@@ -40,6 +40,11 @@
  * miscellaneous
  */
 
+/* make the compiler shut up about unused variables */
+#ifndef USUSED
+# define UNUSED(var)   ((var)=(var))
+#endif
+
 /* never use this function directly.  use GPERL_CALL_BOOT. */
 void _gperl_call_XS (pTHX_ void (*subaddr) (pTHX_ CV *), CV * cv, SV ** mark);
 
@@ -62,6 +67,9 @@ void gperl_croak_gerror (const char * prefix, GError * err);
 
 gpointer gperl_alloc_temp (int nbytes);
 
+
+/* internal trickery */
+gpointer gperl_type_class (GType type);
 /*
  * enums and flags
  */
@@ -96,7 +104,7 @@ const char * gperl_package_from_type (GType type);
  * in GObjects reliably.
  */
 #define GPERL_TYPE_SV	(gperl_sv_get_type ())
-GType gperl_sv_get_type (void); //G_CONST_RETURN;
+GType gperl_sv_get_type (void) G_GNUC_CONST;
 SV * gperl_sv_copy (SV * sv);
 void gperl_sv_free (SV * sv);
 
@@ -190,12 +198,18 @@ typedef GObject GObject_noinc;
 /*
  * GSignal.xs
  */
+SV * newSVGSignalFlags (GSignalFlags flags);
+GSignalFlags SvGSignalFlags (SV * sv);
+SV * newSVGSignalInvocationHint (GSignalInvocationHint * ihint);
 
-gulong gperl_signal_connect (SV            * instance,
-                             char          * detailed_signal,
-                             SV            * callback,
-                             SV            * data,
-                             GConnectFlags   flags);
+void gperl_signal_set_marshaller_for (GType             instance_type,
+                                      char            * detailed_signal,
+                                      GClosureMarshal   marshaller);
+gulong gperl_signal_connect          (SV              * instance,
+                                      char            * detailed_signal,
+                                      SV              * callback,
+                                      SV              * data,
+                                      GConnectFlags     flags);
 
 
 /*
@@ -213,9 +227,15 @@ struct _GPerlClosure {
 /* evaluates to true if the instance and data are to be swapped on invocation */
 #define GPERL_CLOSURE_SWAP_DATA(gpc)	((gpc)->swap)
 
-GClosure * gperl_closure_new (SV * callback, 
-			      SV * data, 
-			      gboolean swap);
+/* this is the one you want. */
+GClosure * gperl_closure_new                 (SV              * callback, 
+                                              SV              * data, 
+                                              gboolean          swap);
+/* very scary, use only if you really know what you are doing */
+GClosure * gperl_closure_new_with_marshaller (SV              * callback, 
+                                              SV              * data, 
+                                              gboolean          swap,
+                                              GClosureMarshal   marshaller);
 
 /*
  * GPerlCallback
@@ -248,9 +268,13 @@ void            gperl_callback_invoke  (GPerlCallback * callback,
  */
 
 int  gperl_install_exception_handler (GClosure * closure);
-void gperl_remove_exception_handler  (int tag);
+void gperl_remove_exception_handler  (guint tag);
 void gperl_run_exception_handlers    (void);
 
+/*
+ * to be used by extensions...
+ */
+gint gperl_handle_logs_for (const gchar * log_domain);
 
 /*
  * gparamspec.h / GParamSpec.xs
@@ -270,8 +294,8 @@ GParamFlags SvGParamFlags (SV * sv);
 	  : "NULL")
 #define GPERL_WRAPPER_VITALS(w)	\
 	((SvTRUE (w))					\
-	  ? (SvROK (w))					\
-	    (? form ("SvRV(%p)->%s(%p)[%d]", (w),	\
+	  ? ((SvROK (w))				\
+	    ? form ("SvRV(%p)->%s(%p)[%d]", (w),	\
 		     sv_reftype (SvRV (w), TRUE),	\
 		     SvRV (w), SvREFCNT (SvRV (w)))	\
 	     : "[not a reference!]")			\
